# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]
### Added
### Changed
### Fixed
### Removed

## [1.4.2] - 2023-08-19
### Added
- Add Wagtail 5.1 support.
- Forked to cjkcms-color-panel pypi package.
- Original app name still left as `wagtail_color_panel` for drop-in replacement.

## [1.4.1] - 2023-02-19
### Added
- Add Wagtail 4.1 and 4.2 support (@marteinn)

### Fixed
- Add github issue template

### Removed
- Drop Wagtail 2.16 support (@marteinn)

## [1.4.0] - 2022-07-03
### Added
- Add support for Wagtail 3.0 (@BrianXu20)

### Removed
- Drop support for all Wagtail versions before 2.15 (@BrianXu20)

## [1.3.1] - 2022-01-08
### Added
- Add Python 3.10 support
- Add Wagtail 2.14 and 2.15 support

### Removed
- Drop Python 3.6 support

## [1.3.0] - 2021-09-27
### Added
- Add support for Wagtail 2.13+ (@marts)

### Removed
- Drop support for Wagtail 2.12 and older

## [1.2.0] - 2020-01-10
### Added
- Add additional text field for handling color values manually (@marts)
